@@ -3,13 +3,15 @@ Main interface for ce service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ce import CostExplorerClient
+    from mypy_boto3_ce import CostExplorerClient
 
     session = boto3.Session()
 
     client: CostExplorerClient = boto3.client("ce")
     session_client: CostExplorerClient = session.client("ce")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -66,38 +68,38 @@ class Exceptions:
 
 class CostExplorerClient:
     """
-    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client)
+    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.can_paginate)
         """
 
     def create_cost_category_definition(
         self,
         Name: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
-        Rules: List[CostCategoryRuleTypeDef],
+        Rules: List["CostCategoryRuleTypeDef"],
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         """
 
     def generate_presigned_url(
@@ -108,38 +110,38 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         """
 
     def get_cost_and_usage(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
-        GroupBy: List[GroupDefinitionTypeDef] = None,
+        GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         """
 
     def get_cost_and_usage_with_resources(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
-        GroupBy: List[GroupDefinitionTypeDef] = None,
+        GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         """
 
     def get_cost_forecast(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         Metric: Literal[
             "BLENDED_COST",
             "UNBLENDED_COST",
@@ -150,16 +152,16 @@ class CostExplorerClient:
             "NORMALIZED_USAGE_AMOUNT",
         ],
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"],
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         """
 
     def get_dimension_values(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         Dimension: Literal[
             "AZ",
             "INSTANCE_TYPE",
@@ -196,20 +198,20 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         """
 
     def get_reservation_coverage(
         self,
-        TimePeriod: DateIntervalTypeDef,
-        GroupBy: List[GroupDefinitionTypeDef] = None,
+        TimePeriod: "DateIntervalTypeDef",
+        GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextPageToken: str = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         """
 
     def get_reservation_purchase_recommendation(
@@ -227,50 +229,50 @@ class CostExplorerClient:
             "MEDIUM_UTILIZATION",
             "HEAVY_UTILIZATION",
         ] = None,
-        ServiceSpecification: ServiceSpecificationTypeDef = None,
+        ServiceSpecification: "ServiceSpecificationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         """
 
     def get_reservation_utilization(
         self,
-        TimePeriod: DateIntervalTypeDef,
-        GroupBy: List[GroupDefinitionTypeDef] = None,
+        TimePeriod: "DateIntervalTypeDef",
+        GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         NextPageToken: str = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         """
 
     def get_rightsizing_recommendation(
         self,
         Service: str,
-        Filter: ExpressionTypeDef = None,
-        Configuration: RightsizingRecommendationConfigurationTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
+        Configuration: "RightsizingRecommendationConfigurationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         """
 
     def get_savings_plans_coverage(
         self,
-        TimePeriod: DateIntervalTypeDef,
-        GroupBy: List[GroupDefinitionTypeDef] = None,
+        TimePeriod: "DateIntervalTypeDef",
+        GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
@@ -289,47 +291,47 @@ class CostExplorerClient:
         AccountScope: Literal["PAYER", "LINKED"] = None,
         NextPageToken: str = None,
         PageSize: int = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         """
 
     def get_savings_plans_utilization(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         """
 
     def get_savings_plans_utilization_details(
         self,
-        TimePeriod: DateIntervalTypeDef,
-        Filter: ExpressionTypeDef = None,
+        TimePeriod: "DateIntervalTypeDef",
+        Filter: "ExpressionTypeDef" = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         """
 
     def get_tags(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         SearchString: str = None,
         TagKey: str = None,
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_tags)
         """
 
     def get_usage_forecast(
         self,
-        TimePeriod: DateIntervalTypeDef,
+        TimePeriod: "DateIntervalTypeDef",
         Metric: Literal[
             "BLENDED_COST",
             "UNBLENDED_COST",
@@ -340,26 +342,26 @@ class CostExplorerClient:
             "NORMALIZED_USAGE_AMOUNT",
         ],
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"],
-        Filter: ExpressionTypeDef = None,
+        Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         """
 
     def update_cost_category_definition(
         self,
         CostCategoryArn: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
-        Rules: List[CostCategoryRuleTypeDef],
+        Rules: List["CostCategoryRuleTypeDef"],
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         """
